@@ -44,8 +44,8 @@ class Decompiler(Service):
         :param architecture: Architecture. The precise meaning depends on the
             used `mode`.
         :type architecture: str
-        :param file_format: File format. The precise meaning depends on the
-            used `mode`.
+        :param file_format: File format. File format to be used when compiling
+            input C source files.
         :type file_format: str
         :param comp_compiler: Compiler to be used when compiling input C source
             files.
@@ -71,9 +71,9 @@ class Decompiler(Service):
         :param sel_decomp_decoding: What instructions should be decoded when
             either `sel_decomp_funcs` or `sel_decomp_ranges` is given?
         :type sel_decomp_decoding: str
-        :param raw_endian: Endianness of the raw machine code (``'little'`` or
+        :param endian: Endianness of the machine code (``'little'`` or
             ``'big'``). Only for the ``raw`` `mode`.
-        :type raw_endian: str
+        :type endian: str
         :param raw_entry_point: Virtual memory address where execution
             flow should start in the raw machine code. Only for the ``raw``
             `mode`.
@@ -82,6 +82,12 @@ class Decompiler(Service):
             machine code will be placed in virtual memory. Only for the
             ``raw`` `mode`.
         :type raw_section_vma: str
+        :param ar_index: Index of the object file in the input archive to be
+            decompiled when decompiling an archive.
+        :type ar_index: int/str
+        :param ar_name: Name of the object file in the input archive to be
+            decompiled when decompiling an archive.
+        :type ar_name: str
         :param generate_cg: Should a call graph be generated?
         :type generate_cg: bool
         :param generate_cfgs: Should control-flow graphs for all functions be
@@ -133,13 +139,15 @@ class Decompiler(Service):
         self._add_param_when_given('comp_compiler', params, kwargs)
         self._add_param_when_given('comp_debug', params, kwargs)
         self._add_param_when_given('comp_strip', params, kwargs)
-        self._add_comp_optimizations_param_when_given(params, kwargs)
+        self._add_param_when_given('comp_optimizations', params, kwargs)
         self._add_sel_decomp_funcs_param_when_given(params, kwargs)
         self._add_sel_decomp_ranges_param_when_given(params, kwargs)
         self._add_param_when_given('sel_decomp_decoding', params, kwargs)
-        self._add_param_when_given('raw_endian', params, kwargs)
+        self._add_endian_param_when_given(params, kwargs)
         self._add_param_when_given('raw_entry_point', params, kwargs)
         self._add_param_when_given('raw_section_vma', params, kwargs)
+        self._add_param_when_given('ar_index', params, kwargs)
+        self._add_param_when_given('ar_name', params, kwargs)
         self._add_param_when_given('generate_archive', params, kwargs)
         self._add_param_when_given('generate_cg', params, kwargs)
         self._add_param_when_given('generate_cfgs', params, kwargs)
@@ -155,7 +163,7 @@ class Decompiler(Service):
 
     def _add_pdb_file_when_given(self, files, kwargs):
         """Adds a PDB file to `files` when it was given."""
-        pdb_file = kwargs.get('pdb_file', None)
+        pdb_file = kwargs.get('pdb_file')
         if pdb_file is not None:
             files['pdb'] = File(pdb_file)
 
@@ -174,30 +182,11 @@ class Decompiler(Service):
         """
         return 'c' if input_file.name.lower().endswith('.c') else 'bin'
 
-    def _add_param_when_given(self, param, params, kwargs):
-        """Adds `param` to `params` when given in `kwargs`."""
-        value = kwargs.get(param, None)
-        if value is not None:
-            params[param] = value
-
-    def _add_comp_optimizations_param_when_given(self, params, kwargs):
-        """Adds the ``comp_optimizations`` parameter to `params` when given in
-        `kwargs`.
-        """
-        value = kwargs.get('comp_optimizations', None)
-        if value is not None:
-            # The retdec.com API expects the optimization level to start with a
-            # dash (e.g. "-O1" instead of just "O1"). To be user-friendly,
-            # allow passing just "O1" and add the dash automatically.
-            if not value.startswith('-'):
-                value = '-' + value
-            params['comp_optimizations'] = value
-
     def _add_sel_decomp_funcs_param_when_given(self, params, kwargs):
         """Adds the ``sel_decomp_funcs`` parameter to `params` when given in
         `kwargs`.
         """
-        value = kwargs.get('sel_decomp_funcs', None)
+        value = kwargs.get('sel_decomp_funcs')
         if value is not None:
             if not isinstance(value, str):
                 value = ','.join(value)
@@ -225,12 +214,21 @@ class Decompiler(Service):
                 return hex(address)
             return str(address)
 
-        value = kwargs.get('sel_decomp_ranges', None)
+        value = kwargs.get('sel_decomp_ranges')
         if value is not None:
             if not isinstance(value, str):
                 value = ranges2str(value)
             params['sel_decomp_ranges'] = value
 
+    def _add_endian_param_when_given(self, params, kwargs):
+        """Adds the ``endian`` parameter to `params` when given in `kwargs`.
+        """
+        # Since RetDec 2.2, the 'raw_endian' parameter has been renamed to
+        # 'endian'. However, the original name should still be supported.
+        endian = kwargs.get('endian', kwargs.get('raw_endian'))
+        if endian is not None:
+            params['endian'] = endian
+
     def __repr__(self):
         return '<{} api_url={!r}>'.format(
             __name__ + '.' + self.__class__.__name__,
