@@ -329,8 +329,16 @@ def parse_args(argv):
         dest='file_format',
         metavar='FORMAT',
         choices=['elf', 'pe'],
-        help='File format to force when compiling C source code or when '
-             'decompiling raw machine code. Choices: %(choices)s. Default: elf.'
+        help='File format to force when compiling C source code. '
+             'Choices: %(choices)s. Default: elf.'
+    )
+    parser.add_argument(
+        '--endian',
+        dest='endian',
+        metavar='ENDIAN',
+        choices=['little', 'big'],
+        help='Endianness of the machine code (bin and raw modes only). '
+             'Choices: %(choices)s. Default: little.'
     )
     parser.add_argument(
         '-l', '--target-language',
@@ -426,14 +434,6 @@ def parse_args(argv):
         help='What should be decoded in a selective decompilation? '
              'Choices: %(choices)s. Default: everything.'
     )
-    parser.add_argument(
-        '--raw-endian',
-        dest='raw_endian',
-        metavar='ENDIAN',
-        choices=['little', 'big'],
-        help='Endianness of the machine code (raw mode only). '
-             'Choices: %(choices)s. Default: little.'
-    )
     parser.add_argument(
         '--raw-entry-point',
         dest='raw_entry_point',
@@ -448,6 +448,20 @@ def parse_args(argv):
         help='Address where the section created from the machine '
              'code will be placed in virtual memory (raw mode only).'
     )
+    parser.add_argument(
+        '--ar-index',
+        dest='ar_index',
+        metavar='INDEX',
+        help='Index of the object file in the input archive to be '
+             'decompiled when decompiling an archive.'
+    )
+    parser.add_argument(
+        '--ar-name',
+        dest='ar_name',
+        metavar='NAME',
+        help='Name of the object file in the input archive to be '
+             'decompiled when decompiling an archive.'
+    )
     parser.add_argument(
         '--with-cg',
         dest='generate_cg',
@@ -558,9 +572,11 @@ def main(argv=None):
     add_decompilation_param_when_given(args, params, 'sel_decomp_funcs')
     add_decompilation_param_when_given(args, params, 'sel_decomp_ranges')
     add_decompilation_param_when_given(args, params, 'sel_decomp_decoding')
-    add_decompilation_param_when_given(args, params, 'raw_endian')
+    add_decompilation_param_when_given(args, params, 'endian')
     add_decompilation_param_when_given(args, params, 'raw_entry_point')
     add_decompilation_param_when_given(args, params, 'raw_section_vma')
+    add_decompilation_param_when_given(args, params, 'ar_index')
+    add_decompilation_param_when_given(args, params, 'ar_name')
     add_decompilation_param_when_given(args, params, 'generate_cg')
     add_decompilation_param_when_given(args, params, 'generate_cfgs')
     add_decompilation_param_when_given(args, params, 'generate_archive')
